@@ -14,7 +14,7 @@ BEGIN {
     use vars        qw[$VERSION @ISA $VERBOSE $CACHE @EXPORT_OK $ERROR];
     use Exporter;
     @ISA        =   qw[Exporter];
-    $VERSION    =   0.05;
+    $VERSION    =   '0.08';
     $VERBOSE    =   0;
 
     @EXPORT_OK  =   qw[check_install can_load requires];
@@ -38,7 +38,7 @@ Module::Load::Conditional - Looking up module information / loading at runtime
     };
 
     print can_load( modules => $use_list )
-            ? 'all modules loaded succesfully'
+            ? 'all modules loaded successfully'
             : 'failed to load required modules';
 
 
@@ -63,8 +63,8 @@ Module::Load::Conditional - Looking up module information / loading at runtime
 
     ### The last error that happened during a call to 'can_load'
     my $err = $Module::Load::Conditional::ERROR;
-    
-    
+
+
 =head1 DESCRIPTION
 
 Module::Load::Conditional provides simple ways to query and possibly load any of
@@ -176,7 +176,7 @@ sub check_install {
             }
 
             if (!UNIVERSAL::isa($fh, 'GLOB')) {
-                warn loc(q[Can not open file '%1': %2], $file, $!) 
+                warn loc(q[Cannot open file '%1': %2], $file, $!)
                         if $args->{verbose};
                 next;
             }
@@ -189,7 +189,7 @@ sub check_install {
 
             $fh = new FileHandle;
             if (!$fh->open($filename)) {
-                warn loc(q[Can not open file '%1': %2], $file, $!)
+                warn loc(q[Cannot open file '%1': %2], $file, $!)
                         if $args->{verbose};
                 next;
             }
@@ -199,6 +199,9 @@ sub check_install {
 
         while (local $_ = <$fh> ) {
 
+	    ### skip commented out lines, they won't eval to anything.
+	    next if /^\s*#/;
+
             ### the following regexp comes from the ExtUtils::MakeMaker
             ### documentation.
             if ( /([\$*])(([\w\:\']*)\bVERSION)\b.*\=/ ) {
@@ -250,7 +253,7 @@ C<can_load> will take a list of modules, optionally with version
 numbers and determine if it is able to load them. If it can load *ALL*
 of them, it will. If one or more are unloadable, none will be loaded.
 
-This is particularly usefull if you have More Than One Way (tm) to
+This is particularly useful if you have More Than One Way (tm) to
 solve a problem in a program, and only wish to continue down a path
 if all modules could be loaded, and not load them if they couldn't.
 
@@ -269,15 +272,15 @@ assumed to be good enough.
 
 =item verbose
 
-This controls whether warnings should be printed if a module failed 
-to load. 
+This controls whether warnings should be printed if a module failed
+to load.
 The default is to use the value of $Module::Load::Conditional::VERBOSE.
 
 =item nocache
 
-C<can_load> keeps it's results in a cache, so it will not load the
+C<can_load> keeps its results in a cache, so it will not load the
 same module twice, nor will it attempt to load a module that has
-already failed to load before. By default, C<can_load> will check it's
+already failed to load before. By default, C<can_load> will check its
 cache, but you can override that by setting C<nocache> to true.
 
 =cut
@@ -326,7 +329,7 @@ sub can_load {
                     && defined $CACHE->{$mod}->{usable}
                     && (($CACHE->{$mod}->{version}||0) >= $href->{$mod})
             ) {
-                $error = loc( q[Already tried to use '%1', which was unsuccesful], $mod);
+                $error = loc( q[Already tried to use '%1', which was unsuccessful], $mod);
                 last BLOCK;
             }
 
@@ -388,13 +391,13 @@ sub can_load {
 =head2 requires
 
 C<requires> can tell you what other modules a particular module
-requires. This is particularly usefull when you're intending to write
-a module for public release and are listing it's prerequisites.
+requires. This is particularly useful when you're intending to write
+a module for public release and are listing its prerequisites.
 
 C<requires> takes but one argument: the name of a module.
 It will then first check if it can actually load this module, and
 return undef if it can't.
-Otherwise, it will return a list of modules and pragma's that would
+Otherwise, it will return a list of modules and pragmas that would
 have been loaded on the module's behalf.
 
 Note: The list C<require> returns has originated from your current
@@ -410,9 +413,9 @@ sub requires {
         return undef;
     }
 
-    my $lib = join " ", map { "-I$_" } @INC;
+    my $lib = join " ", map { qq["-I$_"] } @INC;
     my $cmd = qq[$^X $lib -M$who -e"print(join(qq[\\n],keys(%INC)))"];
-    
+
     return  sort
                 grep { !/^$who$/  }
                 map  { chomp; s|/|::|g; $_ }
@@ -432,7 +435,7 @@ following global variables:
 =head2 $Module::Load::Conditional::VERBOSE
 
 This controls whether Module::Load::Conditional will issue warnings and
-explenations as to why certain things may have failed. If you set it
+explanations as to why certain things may have failed. If you set it
 to 0, Module::Load::Conditional will not output any warnings.
 The default is 0;
 
